/***************************************************************************
 *  Statusled ist jeweils eine 2-PIN-Duo-LED
 * 	4 - Zustnde:
 *		OFF 	Beide Pins aus
 *		GREEN	PinA = ON, PinB = OFF
 *		RED		PinA = OFF, PinB = ON
 *		YELLOW	Schneller Wechsel von RED/GREEN
 ***************************************************************************/
#include <inttypes.h>
#include <avr/io.h>

#include "portconfig.h";
#include "timer.h";
#include "led.h";

/***************************************************************************
 * 
 * Initialisierung
 * Ausgnge setzen, LEDs aus
 * 
 ***************************************************************************/
void ledInitialize(void)
{
	//Pins als Output setzen
	LED_DDR = (1<<LED1_PIN_G)|(1<<LED1_PIN_R)|(1<<LED2_PIN_G)|(1<<LED2_PIN_R);

	//Beim Start: Alles Aus
	ledstatus = 0;
}

/***************************************************************************
 * 
 * Status fr eine LED setzen
 * PinG 	Pin Grn
 * PinR		Pin Rot
 * status	Anzeigestatus
 * 
 ***************************************************************************/
void ledSetStatus(uint8_t pinGreen, uint8_t pinRed, uint8_t status)
{
	//Erstmal beide Pins aus
	LED_PORT &= ~((1 << pinGreen) | (1 << pinRed));

	//LED aktiv?
	if (status != 0)
	{
		//Wenn LED blinkt, sind wir dann in dem Interval an dem die LED leuchtet?
		//Bzw leuchtet die LED dauerhaft?
		if (((bit_is_set(status, LED_BLINK))&& (timer0IntervalCount < TIMER0_BLINK_CMP))
		   |(bit_is_clear(status, LED_BLINK)))
		{
			//LED leuchtet Grn
			if (bit_is_set(status, LED_GREEN)) 
				LED_PORT |= (1 << pinGreen);
			else
				//LED leuchtet Rot
				if (bit_is_set(status, LED_RED))
					LED_PORT |= (1 << pinRed);
				else
					//LED leuchtet Gelb
					if (bit_is_set(status, LED_YELLOW))
					{
						//TimerIntervall gerade => LED Rot, ungerade => LED grn
						if ((timer0IntervalCount & 1)==0) //LED wechselt mit 1kHz zw. Rot und Gruen => Gelb
							LED_PORT |= (1 << pinGreen);
						else
							LED_PORT |= (1 << pinRed); 
					}
					//else {}; //kann man hier her kommen?
		}
	}
}

/***************************************************************************
 * 
 * LED-Anzeige aktualisieren
 * 
 ***************************************************************************/
void ledRefresh(void)
{
	//Erste LED
	ledSetStatus(LED1_PIN_G, LED1_PIN_R, ledstatus);

	//Zweite LED (Status befindet sich in den 4 hheren Bit
	ledSetStatus(LED2_PIN_G, LED2_PIN_R, ledstatus>>4);
}


