#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/signal.h>
#include <avr/eeprom.h>

#include "portconfig.h";
#include "led.h";
#include "pwm.h";
#include "timer.h"
#include "button.h"
#include "akku.h"
#include "globals.h"
#include "eeprom.h"
#include "adc.h"
#include "selftest.h"

void init(void);

volatile uint8_t doactionflag;

/***************************************************************************
 * 
 * Counter0 Interrupt
 * 
 * f=1Khz
 *
 ***************************************************************************/
SIGNAL(SIG_OVERFLOW0)
{
	doactionflag = 1;
}

/*
*/
void doAction(void)
{
	//Zustzlicher Taktdivider, u.a. fr Blinken der LEDs
	if (++timer0IntervalCount == TIMER0_MAX_INT) 
		timer0IntervalCount = 0;
	
 	//Tastenstatus bestimmen
	buttonReadStatus();

	//Und auswerten
	if (bit_is_set(buttonstatus, BTN_PRESSED))
	{
		if (bit_is_set(buttonstatus, BTN_LONG))
		{
			//Langer Tastendruck
			switch (controllerstatus)
			{
				case STAT_HAL100: 	controllerstatus = STAT_LED; break;
				case STAT_HAL50: 	controllerstatus = STAT_LED; break;
				case STAT_LED: 		controllerstatus = STAT_OFF; break;
			}
		}
		else
		{
			//Kurzer Tastendruck
			if ((controllerstatus++)==STAT_HAL100) 
				controllerstatus=STAT_HAL50;
		};
	}

	//LED-Anzeige aktualisieren
	//Statusled fr den Lampenstatus 
	ledstatus = 0;	
	switch (controllerstatus)
	{
		case STAT_LED:		ledstatus = (1<<LED_GREEN);	break;
		case STAT_HAL50:	ledstatus = (1<<LED_YELLOW);	break;
		case STAT_HAL100:	ledstatus = (1<<LED_RED);		break;
	}

	if (bit_is_set(buttonstatus, BTN_LONG))
		ledstatus |= (1<<LED_BLINK);


	//Akkustand ermitteln
	akkuGetStatus();

	//Akkustatusled
	switch (akkustatus)
	{
		case 0:	ledstatus |= (1<<LED2_RED)|(1<<LED2_BLINK); 		break;
		case 1:	ledstatus |= (1<<LED2_RED); 		break;
		case 2:	ledstatus |= (1<<LED2_YELLOW)|(1<<LED2_BLINK); 	break;
		case 3:	ledstatus |= (1<<LED2_YELLOW); 	break;
		case 4:	ledstatus |= (1<<LED2_GREEN)|(1<<LED2_BLINK); 	break;
		case 5:	ledstatus |= (1<<LED2_GREEN); 	break;
	}
		

	ledRefresh();

	//PWM-Ausgnge setzen
	pwmSetOutput();
	//PWM1OUT = akkustatus;
	//PWM2OUT = akkustatus;
}

/***************************************************************************
 * 
 * Initialization
 * 
 ***************************************************************************/
void init(void)
{
	controllerstatus = 0;

	timerInitialize();	//Timerroutinen initalisieren
	buttonInitialize();	//Taster initialisieren
	ledInitialize();

	pwmInitialize();	//PWM-Ausgnge initialisieren
	akkuInitialize();	//A/D-Wandler initiieren
}

/***************************************************************************
 * 
 * Programmeinstiegsroutine
 * 
 ***************************************************************************/
int main(void)
{
 	//Alles initialisieren
	init();

	//Selbstest durchfhren
	doSelfTest();

//	uint8_t temp;
//	temp = adcReadValue();
//	eeprom_write_byte(&eeFooByte, temp); 

	
	//ActionFlag auf 1, damit beim 1. Durchlauf alles einmal ausgefhrt wird
	doactionflag = 1;

	//Interrupts aktivieren
  	sei();	

	//Programmschleife, Warten bis ActionFlag durch Timer auf 1 gesetzt wird
	while (1)
		if (doactionflag)
		{
			//Alle Aktionen ausfhren
			doAction();

			//ActionFlag lschen
			doactionflag = 0;
		}

	return 0;
}
