#include <avr/io.h>
#include "portconfig.h"
#include "globals.h"

#include "pwm.h"


uint8_t lamp1_pwmlevels[] = 
	{
		0x00, 	//STAT_OFF
		0xFF,	//STAT_LED 
		0x00,	//STAT_HAL50  
		0x00, 	//STAT_HAL100
	};

uint8_t lamp2_pwmlevels[] = 
	{
		0x00, 	//STAT_OFF
		0x00,	//STAT_LED 
		100,	//STAT_HAL50 //50% Helligkeit ~15W
		255, 	//STAT_HAL100
	};


/***************************************************************************
 * 
 * Initialisieren
 * 
 ***************************************************************************/
void pwmInitialize(void)
{
	/*
	   PWM1A	PWM Output Pin A enable
   	*/
	TCCR1A = (1<<COM1A1)|(1<<COM1B1)|(1<<PWM1A)|(1<<PWM1B);

	/* Einstellen der PWM-Frequenz
		Phase Correct: 	PWM = 1Mhz / (Prescaler * 510)
		Fast PWM:		PWM = 1Mhz / (Prescaler * OCR1C)
		
		CS13 	CS12 	CS11 	CS10
		0		0 		0 		0 		stopped.
		0		0 		0 		1 		1
		0		0 		1 		0 		2 	
		0		0 		1 		1 		4 		
		0		1 		0 		0 		8 		
		0		1 		0 		1 		16 		
		0		1 		1 		0 		32 		
		0		1 		1 		1 		64 		
		1		0 		0 		0 		128 	
		1		0 		0 		1 		256 	
		1		0 		1 		0 		512
		1		0 		1 		1 		1024
		1		1 		0 		0 		2048
		1		1 		0 		1 		4096
		1		1 		1 		0 		8192
		1		1 		1 		1 		16384
	*/

	TCCR1B 	= (0<<CS13)|(0<<CS12)|(1<<CS11)|(0<<CS10); //1
	OCR1C	= 255; 
	//Ergibt gemessene 3,9Khz

	// Interrupts fr Timer1 deaktivieren
	TIMSK &= ~(1<<TOIE1);

	//Output setzen
	DDRB |= (1<<PWM1_PIN)|(1<<PWM2_PIN);

	PWM1OUT = 0;
	PWM2OUT = 0;
}

void pwmSetOutput()
{	
	PWM1OUT = lamp1_pwmlevels[controllerstatus];
	PWM2OUT = lamp2_pwmlevels[controllerstatus];


}

